#
# Conditional build:
%bcond_without	asm	# x86 assembler
%bcond_without	doc	# don't build doc
%bcond_with	tests	# build tests (not useful, creates libgtest.a)
%bcond_without	ssse3	# use SSSE3 instructions (Intel since Core2, Via Nano)

%ifnarch %{ix86} %{x8664} x32
%undefine	with_asm
%endif

%if "%{pld_release}" == "ac"
# not supported by compiler
%undefine	with_ssse3
%endif

Summary:	VP8, a high-quality video codec
Summary(pl.UTF-8):	VP8 - kodek obrazu wysokiej jakości
Name:		libvpx
Version:	1.10.0
Release:	1
License:	BSD
Group:		Libraries
# original download URL: http://downloads.webmproject.org/releases/webm/index.html
# ...but use github mirror to get consistent tarballs
#Source0Download: https://github.com/webmproject/libvpx/releases
Source0:	https://github.com/webmproject/libvpx/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	cded283be38dc0078c3fbe751722efc5
URL:		https://www.webmproject.org/
BuildRequires:	doxygen
%{?with_tests:BuildRequires:	libstdc++-devel}
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.673
BuildRequires:	sed >= 4.0
%{?with_asm:BuildRequires:	yasm >= 0.8}
%if %{with doc}
BuildRequires:	%{php_name}-pcre
BuildRequires:	%{php_name}-program
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define	generic_target	generic-gnu
%define	vpxtarget	%{generic_target}
%ifarch %{x8664}
%define	vpxtarget	x86_64-linux-gcc
%endif
%ifarch %{ix86}
%define	vpxtarget	x86-linux-gcc
%endif
%ifarch ppc
%define	vpxtarget	ppc32-linux-gcc
%endif
%ifarch ppc64
%define	vpxtarget	ppc64-linux-gcc
%endif
%ifarch aarch64
%define	vpxtarget	arm64-linux-gcc
%endif

%description
VP8, a high-quality video codec.

%description -l pl.UTF-8
VP8 - kodek obrazu wysokiej jakości.

%package devel
Summary:	Header files for libvpx
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki libvpx
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for libvpx library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki libvpx.

%package static
Summary:	Static libvpx library
Summary(pl.UTF-8):	Statyczna biblioteka libvpx
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libvpx library.

%description static -l pl.UTF-8
Statyczna biblioteka libvpx.

%package tools
Summary:	VPX decoding/encoding tools
Summary(pl.UTF-8):	Narzędzia do kodowania/dekodowania formatu VPX
Group:		Applications/Graphics
Requires:	%{name} = %{version}-%{release}

%description tools
VPX decoding/encoding tools.

%description tools -l pl.UTF-8
Narzędzia do kodowania/dekodowania formatu VPX.

%prep
%setup -q

%build
install -d obj
cd obj
# not autoconf configure
CC="%{__cc}" \
CXX="%{__cxx}" \
CFLAGS="%{rpmcflags} %{rpmcppflags}" \
../configure \
%if %{with asm}
	--as=yasm \
%endif
	--target=%{vpxtarget} \
	--enable-shared \
	%{!?with_ssse3:--disable-ssse3} \
	--disable-optimizations \
	--%{!?with_tests:dis}%{?with_tests:en}able-unit-tests \
	--%{!?with_doc:dis}%{?with_doc:en}able-docs \
	--%{!?with_doc:dis}%{?with_doc:en}able-install-docs \
	--enable-vp8 \
	--enable-vp8 \
	--enable-postproc \
	--enable-runtime-cpu-detect

%{__make} verbose=true target=libs \
	HAVE_GNU_STRIP=no \
	LDFLAGS="%{rpmldflags}"

%{__make} verbose=true target=examples \
	LDFLAGS="%{rpmldflags} -L."

%if %{with doc}
%{__make} verbose=true target=docs
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_bindir},%{_includedir}/vpx,%{_libdir}}

%{__make} -C obj verbose=true install \
	LIBSUBDIR=%{_lib} \
	DIST_DIR=$RPM_BUILD_ROOT%{_prefix}

# redundant minor version symlink (not SONAME)
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libvpx.so.6.4

# adjust prefix and libdir
%{__sed} -i -e 's,^prefix=.*,prefix=%{_prefix},;s,^libdir=.*,libdir=%{_libdir},' $RPM_BUILD_ROOT%{_pkgconfigdir}/vpx.pc

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS CHANGELOG LICENSE PATENTS README
%attr(755,root,root) %{_libdir}/libvpx.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libvpx.so.6

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libvpx.so
%{_includedir}/vpx
%{_pkgconfigdir}/vpx.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libvpx.a

%files tools
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/vpxdec
%attr(755,root,root) %{_bindir}/vpxenc
%changelog
* Sat Apr 24 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libvpx.git;a=log;h=master

* Sat Apr 24 2021 Jakub Bogusz <qboosh@pld-linux.org> a0961f7
- updated to 1.10.0

* Fri Sep 25 2020 Jakub Bogusz <qboosh@pld-linux.org> 7074c8f
- updated to 1.9.0

* Sun May 03 2020 Jan Palus <atler@pld-linux.org> 2831622
- YUV_DISABLE_ASM is gone

* Sun May 03 2020 Jan Palus <atler@pld-linux.org> 5ae0308
- define target for aarch64

* Thu Dec 26 2019 Jan Palus <atler@pld-linux.org> ac3743c
- up to 1.8.2

* Thu Jul 25 2019 Jakub Bogusz <qboosh@pld-linux.org> 61c9fbe
- added comment for symlink rm

* Thu Jul 25 2019 Jan Palus <atler@pld-linux.org> 5696093
- up to 1.8.1

* Fri Mar 15 2019 Jakub Bogusz <qboosh@pld-linux.org> 5d57f49
- simplified Source0 URL

* Sat Mar 02 2019 Jan Palus <atler@pld-linux.org> 8895f18
- up to 1.8.0 (new soname)

* Sat Mar 02 2019 Jan Palus <atler@pld-linux.org> 5df4ed4
- use github mirror for consistent download results

* Sat Nov 10 2018 Jakub Bogusz <qboosh@pld-linux.org> 20665a0
- use dropin

* Fri Nov 09 2018 Jakub Bogusz <qboosh@pld-linux.org> f665043
- updated to 1.7.0 (note: new soname)

* Wed Jan 25 2017 Arkadiusz Miśkiewicz <arekm@maven.pl> f7b6d87
- up to 1.6.1

* Fri Aug 05 2016 Jakub Bogusz <qboosh@pld-linux.org> 59ff159
- split -tools to allow parallel-installable libraries

* Fri Aug 05 2016 Jakub Bogusz <qboosh@pld-linux.org> a608fd0
- updated to 1.6.0 (note: new soname)

* Thu Dec 24 2015 Jakub Bogusz <qboosh@pld-linux.org> 627f753
- noted download URL

* Wed Nov 11 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 05641fc
- up to 1.5.0

* Sun Sep 13 2015 Jan Rękorajski <baggins@pld-linux.org> 30fcd8a
- asm can be enabled on x32 now
- rel 2

* Sat May 23 2015 Elan Ruusamäe <glen@delfi.ee> 68afcbe
- release 1 (by relup.sh)

* Sat May 16 2015 Jakub Bogusz <qboosh@pld-linux.org> 2f02a71
- fixed build

